@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: common.h,v 1.27 2006/08/15 13:20:33 evertonm Exp $ */
+/* $Id: common.h,v 1.28 2007/08/17 17:12:47 evertonm Exp $ */
 
 #ifndef NEPIM_COMMON_H
 #define NEPIM_COMMON_H
@@ -38,11 +38,6 @@ MA 02110-1301 USA
 #define NEPIM_MAX(a, b)      (((a) > (b)) ? (a) : (b))
 #define NEPIM_RANGE(v, a, b) NEPIM_MIN(NEPIM_MAX((v), (a)), (b))
 
-/* Quick and dirty random number generator from NUMERICAL RECIPES IN C:
-   THE ART OF SCIENTIFIC COMPUTING (ISBN 0-521-43108-5). */
-/* BEWARE: '_qseed_' is assigned! */
-#define QRANDOM(_qseed_)  ((_qseed_) = (((_qseed_) * 1664525L) + 1013904223L))
-
 extern const char * const NEPIM_LABEL_PARTIAL;
 extern const char * const NEPIM_LABEL_TOTAL;
 
